@@ -4,7 +4,7 @@ import { join, resolve, dirname, parse as parsePath, relative } from 'path';
 import { inspect } from 'util';
 import Module = require('module');
 let arg: typeof import('arg');
-import { parse, createRequire, hasOwnProperty } from './util';
+import { parse, createRequire, hasOwnProperty, versionGteLt } from './util';
 import {
   EVAL_FILENAME,
   EvalState,
@@ -21,13 +21,13 @@ import {
   VERSION,
   TSError,
   register,
-  versionGteLt,
   createEsmHooks,
   createFromPreloadedConfig,
   DEFAULTS,
+  ExperimentalSpecifierResolution,
 } from './index';
 import type { TSInternal } from './ts-compiler-types';
-import { addBuiltinLibsToObject } from '../dist-raw/node-cjs-helpers';
+import { addBuiltinLibsToObject } from '../dist-raw/node-internal-modules-cjs-helpers';
 import { callInChild } from './child/spawn-child';
 import { findAndReadConfig } from './configuration';
 
@@ -141,6 +141,7 @@ function parseArgv(argv: string[], entrypointArgs: Record<string, any>) {
         '--scope': Boolean,
         '--scopeDir': String,
         '--noExperimentalReplAwait': Boolean,
+        '--experimentalSpecifierResolution': String,
 
         // Aliases.
         '-e': '--eval',
@@ -174,6 +175,8 @@ function parseArgv(argv: string[], entrypointArgs: Record<string, any>) {
         '--log-error': '--logError',
         '--scope-dir': '--scopeDir',
         '--no-experimental-repl-await': '--noExperimentalReplAwait',
+        '--experimental-specifier-resolution':
+          '--experimentalSpecifierResolution',
       },
       {
         argv,
@@ -216,6 +219,7 @@ function parseArgv(argv: string[], entrypointArgs: Record<string, any>) {
     '--scope': scope = undefined,
     '--scopeDir': scopeDir = undefined,
     '--noExperimentalReplAwait': noExperimentalReplAwait,
+    '--experimentalSpecifierResolution': experimentalSpecifierResolution,
     '--esm': esm,
     _: restArgs,
   } = args;
@@ -254,6 +258,7 @@ function parseArgv(argv: string[], entrypointArgs: Record<string, any>) {
     scope,
     scopeDir,
     noExperimentalReplAwait,
+    experimentalSpecifierResolution,
     esm,
   };
 }
@@ -301,6 +306,8 @@ Options:
   --preferTsExts                  Prefer importing TypeScript files over JavaScript files
   --logError                      Logs TypeScript errors to stderr instead of throwing exceptions
   --noExperimentalReplAwait       Disable top-level await in REPL.  Equivalent to node's --no-experimental-repl-await
+  --experimentalSpecifierResolution [node|explicit]
+                                  Equivalent to node's --experimental-specifier-resolution
 `);
 
     process.exit(0);
@@ -362,6 +369,8 @@ function phase3(payload: BootstrapState) {
     argsRequire,
     scope,
     scopeDir,
+    esm,
+    experimentalSpecifierResolution,
   } = payload.parseArgvResult;
   const { cwd, scriptPath } = payload.phase2Result!;
 
@@ -389,6 +398,9 @@ function phase3(payload: BootstrapState) {
     scope,
     scopeDir,
     preferTsExts,
+    esm,
+    experimentalSpecifierResolution:
+      experimentalSpecifierResolution as ExperimentalSpecifierResolution,
   });
 
   if (preloadedConfig.options.esm) payload.shouldUseChildProcess = true;
