@@ -10,7 +10,7 @@ import {
   BIN_PATH_JS,
   CMD_ESM_LOADER_WITHOUT_PROJECT,
   CMD_TS_NODE_WITHOUT_PROJECT_FLAG,
-  contextTsNodeUnderTest,
+  ctxTsNode,
   delay,
   EXPERIMENTAL_MODULES_FLAG,
   nodeSupportsEsmHooks,
@@ -26,7 +26,7 @@ import * as expect from 'expect';
 import type { NodeLoaderHooksAPI2 } from '../';
 import { pathToFileURL } from 'url';
 
-const test = context(contextTsNodeUnderTest);
+const test = context(ctxTsNode);
 
 const exec = createExec({
   cwd: TEST_DIR,
@@ -48,22 +48,24 @@ test.suite('esm', (test) => {
       expect(err).toBe(null);
       expect(stdout).toBe('foo bar baz biff libfoo\n');
     });
-    test('should use source maps', async () => {
-      const { err, stdout } = await exec(
+    test('should use source maps', async (t) => {
+      const { err, stdout, stderr } = await exec(
         `${CMD_ESM_LOADER_WITHOUT_PROJECT} "throw error.ts"`,
         {
           cwd: join(TEST_DIR, './esm'),
         }
       );
       expect(err).not.toBe(null);
+      const expectedModuleUrl = pathToFileURL(
+        join(TEST_DIR, './esm/throw error.ts')
+      ).toString();
       expect(err!.message).toMatch(
         [
-          `${pathToFileURL(join(TEST_DIR, './esm/throw error.ts'))
-            .toString()
-            .replace(/%20/g, ' ')}:100`,
+          `${expectedModuleUrl}:100`,
           "  bar() { throw new Error('this is a demo'); }",
           '                ^',
           'Error: this is a demo',
+          `    at Foo.bar (${expectedModuleUrl}:100:17)`,
         ].join('\n')
       );
     });
@@ -233,8 +235,8 @@ test.suite('esm', (test) => {
       });
     });
 
-    test.suite('unit test hooks', (_test) => {
-      const test = _test.context(async (t) => {
+    test.suite('unit test hooks', ({ context }) => {
+      const test = context(async (t) => {
         const service = t.context.tsNodeUnderTest.create({
           cwd: TEST_DIR,
         });
